#!/bin/sh

if [ $# -ne 3 ]; then
    echo "Usage: $0 <rbs_rb_working_directory> <product_directory> <product_name_prefix> <olas_directory>" >&2
    exit 1
fi

rbs_rb_working_directory=$1
product_directory=$2
product_name_prefix=$3
olas_directory=${DFS_DATA_REDUCED_OLAS}

if [ ! -d ${rbs_rb_working_directory} ]; then
    echo "ERROR: $0: rbs_rb_working_directory=${rbs_rb_working_directory} does not exist or is no directory" >&2
    exit 1
fi

if [ ! -d ${product_directory} ]; then
    echo "ERROR: $0: product_directory=${product_directory} does not exist or is no directory" >&2
    exit 1
fi


#########################
# join partial products #
#########################

result=0
numbers=`find ${rbs_rb_working_directory}/MainJob-01 -name "${product_name_prefix}_01_[0-9][0-9][0-9][0-9].fits" | sed -e 's/^.*\([0-9][0-9][0-9][0-9]\).fits/\1/'`

if test "x$numbers" = "x"; then      
numbers=`find ${rbs_rb_working_directory}/MainJob-1 -name "${product_name_prefix}_1_[0-9][0-9][0-9][0-9].fits" | sed -e 's/^.*\([0-9][0-9][0-9][0-9]\).fits/\1/'`
fi                                                

for number in ${numbers}; do
  parts=`find ${rbs_rb_working_directory} -name "*.fits" | grep "MainJob-[0-9]\+\/${product_name_prefix}_[0-9]\+_${number}.fits" | sort`

  if [ -e ${product_directory}/${product_name_prefix}_${number}.fits ]; then
    echo "WARNING: $0: removing already-existing product ${product_directory}/${product_name_prefix}_${number}.fits" >&2
    rm -f ${product_directory}/${product_name_prefix}_${number}.fits
  fi

  fitsjoin ${parts} ${product_directory}/${product_name_prefix}_${number}.fits

  if [ $? -ne 0 ]; then
    echo "ERROR: $0: fitsjoin failed to create product ${product_directory}/${product_name_prefix}_${number}.fits" >&2
    result=1
    break
  fi
done


############################
# create symlinks for OLAS #
############################

# always create the symlinks as a last step to avoid that OLAS transfers an incomplete set of reduced products
if [ ${result} -eq 0 ]; then
  for number in ${numbers}; do
    RBSLink ${product_directory}/${product_name_prefix}_${number}.fits ${olas_directory}/${product_name_prefix}_${number}.fits
    if [ $? -ne 0 ]; then
      echo "ERROR: $0: RBSLink failed to create the symbolic link ${olas_directory}/${product_name_prefix}_${number}.fits" >&2
      result=1
      break
    fi
  done
fi

if [ ${result} -ne 0 ]; then
  echo "ERROR: $0: execution incomplete due to an unrecoverable problem when processing ${product_name_prefix}_*.fits" >&2
  exit ${result}
fi


####################
# write QC logfile #
####################

instrument=OMEGA
vlt_dictionaries=OBS,DPR,PRIMARY-FITS,PRO,TPL,IRACE,OMEGA_CFG,OMEGA_ICS,OMEGA_OS,OMEGA_TCS
paf_files=`find ${rbs_rb_working_directory} -name "*.paf" | sort`

for file in ${paf_files}; do
  ( cd `dirname ${file}`; \
    QC1LogWriter -s OMEGA \
                 -I ${INS_ROOT}/SYSTEM/Dictionary \
                 -D ${vlt_dictionaries} \
                 -p `basename ${file}` \
  ) >&2
  
  if [ $? -ne 0 ]; then
    echo "ERROR: $0: QC1LogWriter failed on ${paf_file}" >&2
    result=1
    break
  fi
  
done


exit ${result}
